@@ -23,6 +23,10 @@
 
 #include "msolve-data.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int msolve_trace_qq(
         mpz_param_t *mpz_paramp,
         param_t **nmod_param,
@@ -38,6 +42,7 @@ int msolve_trace_qq(
         int32_t la_option,
         int32_t use_signatures,
         int32_t lift_matrix,
+        int *to_split_ptr,
         int32_t info_level,
         int32_t print_gb,
         int32_t pbm_file,
@@ -216,6 +221,18 @@ int64_t export_groebner_qq(
         const int32_t reduce_gb,
         const int32_t pbm_file,
         const int32_t truncate_lifting,
-        const int32_t info_level
+        const int32_t info_level 
         );
+
+// Utility functions to init and deinit data structures
+void real_point_clear(real_point_t pt);
+void mpz_param_init(mpz_param_t param);
+void mpz_param_clear(mpz_param_t param);
+data_gens_ff_t* allocate_data_gens();
+void free_data_gens(data_gens_ff_t* gens);
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif
