@@ -44,15 +44,16 @@
  */
 
 #ifdef NMOD_MAT_POLY_INLINES_C
-#define NMOD_MAT_POLY_INLINE FLINT_DLL
+#define NMOD_MAT_POLY_INLINE
 #else
-#define NMOD_MAT_POLY_INLINE static __inline__
+#define NMOD_MAT_POLY_INLINE static inline
 #endif
 
 #ifndef NMOD_MAT_POLY_H
 #define NMOD_MAT_POLY_H
 
 #include <flint/perm.h>
+#include <flint/nmod_vec.h>
 #include <flint/nmod_mat.h>
 #include <flint/nmod_poly_mat.h>
 
@@ -96,38 +97,37 @@ typedef nmod_mat_poly_struct nmod_mat_poly_t[1];
 
 /** Initialises `matp`. It will have dimensions `r x c` and coefficients modulo
  * `n`. */
-FLINT_DLL void nmod_mat_poly_init(nmod_mat_poly_t matp,
-                                  slong r, slong c,
-                                  mp_limb_t n);
+void nmod_mat_poly_init(nmod_mat_poly_t matp,
+                        slong r, slong c,
+                        ulong n);
 
 /** Initialises `matp`. It will have dimensions `r x c` and coefficients modulo
  * `n`. The caller supplies a precomputed inverse limb generated by
  * `n_preinvert_limb()`. */
-FLINT_DLL void nmod_mat_poly_init_preinv(nmod_mat_poly_t matp,
-                                         slong r, slong c,
-                                         mp_limb_t n, mp_limb_t ninv);
+void nmod_mat_poly_init_preinv(nmod_mat_poly_t matp,
+                               slong r, slong c,
+                               ulong n, ulong ninv);
 
 /** Initialises `matp`. It will have dimensions `r x c` and coefficients modulo
  * `n`. Up to alloc coefficients may be stored in `matp`. Implementation note:
  * the `alloc` matrix coefficients are not initialized. */
-FLINT_DLL void nmod_mat_poly_init2(nmod_mat_poly_t matp,
-                                   slong r, slong c,
-                                   mp_limb_t n,
-                                   slong alloc);
+void nmod_mat_poly_init2(nmod_mat_poly_t matp,
+                         slong r, slong c,
+                         ulong n,
+                         slong alloc);
 
 /** Initialises `matp`. It will have dimensions `r x c` and coefficients
  * modulo~`n`. The caller supplies a precomputed inverse limb generated by
  * n_preinvert_limb(). Up to alloc coefficients may be stored in `matp`.
  * Implementation note: the `alloc` matrix coefficients are not initialized. */
-FLINT_DLL void nmod_mat_poly_init2_preinv(nmod_mat_poly_t matp,
-                                          slong r, slong c,
-                                          mp_limb_t n, mp_limb_t ninv,
-                                          slong alloc);
+void nmod_mat_poly_init2_preinv(nmod_mat_poly_t matp,
+                                slong r, slong c,
+                                ulong n, ulong ninv,
+                                slong alloc);
 
 /** Sets `matp1` to equal `matp2`. It is assumed that these matrices
  * have identical dimensions and modulus. */
-FLINT_DLL void
-nmod_mat_poly_set(nmod_mat_poly_t matp1, const nmod_mat_poly_t matp2);
+void nmod_mat_poly_set(nmod_mat_poly_t matp1, const nmod_mat_poly_t matp2);
 
 
 /** Initialises `matp` using an already initialised modulus `mod`. */
@@ -154,15 +154,15 @@ void nmod_mat_poly_set_mod(nmod_mat_poly_t matp, const nmod_t mod)
 /** Reallocates `matp` to the given length `alloc`. If the current `length` is
  * more than `alloc`, the polynomial is truncated and normalised. If `alloc` is
  * zero, the polynomial is cleared. */
-FLINT_DLL void nmod_mat_poly_realloc(nmod_mat_poly_t matp, slong alloc);
+void nmod_mat_poly_realloc(nmod_mat_poly_t matp, slong alloc);
 
 /** Clears `matp` and releases any memory it used. The matrix polynomial cannot be
 used again until it is initialised. */
-FLINT_DLL void nmod_mat_poly_clear(nmod_mat_poly_t matp);
+void nmod_mat_poly_clear(nmod_mat_poly_t matp);
 
 /** Ensures `matp` has space for at least `alloc` coefficients. This function
  * only ever grows the allocated space, so no data loss can occur. */
-FLINT_DLL void nmod_mat_poly_fit_length(nmod_mat_poly_t matp, slong alloc);
+void nmod_mat_poly_fit_length(nmod_mat_poly_t matp, slong alloc);
 
 /** Sets the length of `matp` to `length`. If `length < matp->length` then the
  * matrix coefficients of `matp` beyond `length` are cleared; otherwise, the
@@ -320,25 +320,25 @@ nmod_mat_poly_get_coeff(nmod_mat_t coeff, const nmod_mat_poly_t matp, slong k)
  * row `i` and column `j` (indexed from zero). No bounds checking is performed.
  * This macro can be used both for reading and writing coefficients.
  */
-#define nmod_mat_poly_entry(matp,k,i,j) \
-    (((matp)->coeffs + (k))->rows[(i)][(j)])
+#define nmod_mat_poly_entry(matp, k, i, j) \
+    nmod_mat_entry((matp)->coeffs + (k), (i), (j))
 
 /** Get the entry at row `i` and column `j` in the coefficient of
  * degree `k` of the matrix polynomial `matp`. */
-NMOD_MAT_POLY_INLINE mp_limb_t
+NMOD_MAT_POLY_INLINE ulong
 nmod_mat_poly_get_entry(const nmod_mat_poly_t matp,
                         slong k, slong i, slong j)
 {
-   return (matp->coeffs + k)->rows[i][j];
+   return nmod_mat_poly_entry(matp, k, i, j);
 }
 
 /** Return a pointer to the entry at row `i` and column `j` of the coefficient
  * of degree `k` of the matrix polynomial `matp` */
-NMOD_MAT_POLY_INLINE mp_limb_t *
+NMOD_MAT_POLY_INLINE ulong *
 nmod_mat_poly_entry_ptr(const nmod_mat_poly_t matp,
                         slong k, slong i, slong j)
 {
-   return (matp->coeffs + k)->rows[i] + j;
+   return &nmod_mat_poly_entry(matp, k, i, j);
 }
 
 /** Set to `x` the entry at row `i` and column `j` in the coefficient of degree
@@ -346,7 +346,7 @@ nmod_mat_poly_entry_ptr(const nmod_mat_poly_t matp,
 NMOD_MAT_POLY_INLINE void
 nmod_mat_poly_set_entry(nmod_mat_poly_t matp,
                         slong k, slong i, slong j,
-                        mp_limb_t x)
+                        ulong x)
 {
     nmod_mat_poly_entry(matp, k, i, j) = x;
 }
@@ -389,29 +389,25 @@ nmod_mat_poly_truncate(nmod_mat_poly_t matp, slong order)
  * Inserts zero coefficients at the lower end. Assumes that `len` and `n`
  are positive, and that `smatp` fits `len + n` elements. Supports aliasing
  between res and poly. */
-FLINT_DLL void
-_nmod_mat_poly_shift_left(nmod_mat_struct * smatp,
-                          const nmod_mat_struct * matp,
-                          slong len,
-                          slong n);
+void _nmod_mat_poly_shift_left(nmod_mat_struct * smatp,
+                               const nmod_mat_struct * matp,
+                               slong len,
+                               slong n);
 
 // TODO
-//FLINT_DLL void
-//_nmod_mat_poly_shift_right(nmod_mat_poly_t smatp,
+//void _nmod_mat_poly_shift_right(nmod_mat_poly_t smatp,
 //                          const nmod_mat_poly_t matp,
 //                          slong len,
 //                          slong n);
 
 /** Sets `smatp` to `matp` shifted left by `n` coeffs. Zero coefficients are
  * inserted. */
-FLINT_DLL void
-nmod_mat_poly_shift_left(nmod_mat_poly_t smatp,
-                         const nmod_mat_poly_t matp,
-                         slong n);
+void nmod_mat_poly_shift_left(nmod_mat_poly_t smatp,
+                              const nmod_mat_poly_t matp,
+                              slong n);
 
 // TODO
-//FLINT_DLL void
-//nmod_mat_poly_shift_right(nmod_mat_poly_t smatp,
+//void nmod_mat_poly_shift_right(nmod_mat_poly_t smatp,
 //                          const nmod_mat_poly_t matp,
 //                          slong n);
 //
@@ -427,7 +423,11 @@ nmod_mat_poly_permute_rows(nmod_mat_poly_t matp,
                            slong * perm_store)
 {
     slong i;
-    mp_limb_t ** mat_tmp = flint_malloc(matp->r * sizeof(mp_limb_t *));
+#if __FLINT_VERSION < 3 || (__FLINT_VERSION == 3 && __FLINT_VERSION_MINOR < 3)
+    ulong ** mat_tmp = flint_malloc(matp->r * sizeof(ulong *));
+#else
+    ulong * mat_tmp = (ulong *) flint_malloc(matp->r * matp->c * sizeof(ulong));
+#endif
 
     /* perm_store[i] <- perm_store[perm_act[i]] */
     if (perm_store)
@@ -436,10 +436,17 @@ nmod_mat_poly_permute_rows(nmod_mat_poly_t matp,
     /* rows[i] <- rows[perm_act[i]]  */
     for (slong k = 0; k < matp->length; k++)
     {
+#if __FLINT_VERSION < 3 || (__FLINT_VERSION == 3 && __FLINT_VERSION_MINOR < 3)
         for (i = 0; i < matp->r; i++)
             mat_tmp[i] = matp->coeffs[k].rows[perm_act[i]];
         for (i = 0; i < matp->r; i++)
             matp->coeffs[k].rows[i] = mat_tmp[i];
+#else
+        for (i = 0; i < matp->r; i++)
+            _nmod_vec_set(mat_tmp + i * matp->c, nmod_mat_entry_ptr(matp->coeffs+k, perm_act[i], 0), matp->c);
+        for (i = 0; i < matp->r; i++)
+            _nmod_vec_set(nmod_mat_entry_ptr(matp->coeffs+k, i, 0), mat_tmp + i * matp->c, matp->c);
+#endif
     }
 
     flint_free(mat_tmp);
@@ -460,10 +467,10 @@ nmod_mat_poly_permute_rows(nmod_mat_poly_t matp,
 //@{
 
 /** Basic print to standard output */
-FLINT_DLL void nmod_mat_poly_print(const nmod_mat_poly_t matp);
+void nmod_mat_poly_print(const nmod_mat_poly_t matp);
 
 /** Pretty print to standard output */
-FLINT_DLL void nmod_mat_poly_print_pretty(const nmod_mat_poly_t matp);
+void nmod_mat_poly_print_pretty(const nmod_mat_poly_t matp);
 
 //@} // doxygen group:  Input / Output
 
@@ -484,11 +491,10 @@ FLINT_DLL void nmod_mat_poly_print_pretty(const nmod_mat_poly_t matp);
  * compatible. The output `coeff` must already be initialized with dimensions
  * `mat1->r x mat2->c`.
  */
-FLINT_DLL void
-nmod_mat_poly_mul_coeff(nmod_mat_t coeff,
-                        const nmod_mat_poly_t mat1,
-                        const nmod_mat_poly_t mat2,
-                        slong k);
+void nmod_mat_poly_mul_coeff(nmod_mat_t coeff,
+                             const nmod_mat_poly_t mat1,
+                             const nmod_mat_poly_t mat2,
+                             slong k);
 
 //@} // doxygen group:  Basic arithmetic
 
@@ -524,20 +530,17 @@ nmod_mat_poly_mul_coeff(nmod_mat_t coeff,
  * careful: probably better to use nmod_poly_init with preinv...
  * but this should have been done in Flint's native poly_mat_init too?
  **/
-FLINT_DLL void
-nmod_mat_poly_init_set_from_nmod_mat(nmod_mat_poly_t matp,
-                                     const nmod_mat_t cmat);
+void nmod_mat_poly_init_set_from_nmod_mat(nmod_mat_poly_t matp,
+                                          const nmod_mat_t cmat);
 
 /** Set the polynomial matrix `pmat` to be a constant polynomial matrix whose
  * constant coefficient is a copy of `cmat`. This assumes `pmat` is already
  * initialized with the same modulus and dimensions as `cmat`.  */
-FLINT_DLL void
-nmod_mat_poly_set_from_nmod_mat(nmod_mat_poly_t matp, const nmod_mat_t cmat);
+void nmod_mat_poly_set_from_nmod_mat(nmod_mat_poly_t matp, const nmod_mat_t cmat);
 
 /** Set from polynomial with matrix coefficients `matp`, truncated at the
  * specified `order` (a nonnegative integer). */
-FLINT_DLL void
-nmod_mat_poly_set_trunc_from_poly_mat(nmod_mat_poly_t matp,
+void nmod_mat_poly_set_trunc_from_poly_mat(nmod_mat_poly_t matp,
                                       const nmod_poly_mat_t pmat,
                                       slong order);
 
@@ -581,11 +584,10 @@ nmod_mat_poly_set_from_poly_mat(nmod_mat_poly_t matp, const nmod_poly_mat_t pmat
 //@{
 
 /** Main mbasis function. */
-FLINT_DLL void
-nmod_mat_poly_mbasis(nmod_mat_poly_t appbas,
-                     slong * shift,
-                     const nmod_mat_poly_t matp,
-                     slong order);
+void nmod_mat_poly_mbasis(nmod_mat_poly_t appbas,
+                          slong * shift,
+                          const nmod_mat_poly_t matp,
+                          slong order);
 
 //@} // doxygen group: M-Basis algorithm (uniform approximant order)
 
